Index: kernel/generic/src/mm/as.c
===================================================================
--- kernel/generic/src/mm/as.c	(revision b3f8fb771f871e7f2bb35ce9339717639e8f86d6)
+++ kernel/generic/src/mm/as.c	(revision c27c988cab02c1a8170e26cd226fd6f2d264a3d1)
@@ -864,5 +864,5 @@
  * @param new New address space.
  */
-void as_switch(as_t *old, as_t *new)
+void as_switch(as_t *old, as_t *replace)
 {
 	ipl_t ipl;
@@ -901,17 +901,17 @@
 	 * Second, prepare the new address space.
 	 */
-	mutex_lock_active(&new->lock);
-	if ((new->cpu_refcount++ == 0) && (new != AS_KERNEL)) {
-		if (new->asid != ASID_INVALID) {
-			list_remove(&new->inactive_as_with_asid_link);
+	mutex_lock_active(&replace->lock);
+	if ((replace->cpu_refcount++ == 0) && (replace != AS_KERNEL)) {
+		if (replace->asid != ASID_INVALID) {
+			list_remove(&replace->inactive_as_with_asid_link);
 		} else {
 			/*
 			 * Defer call to asid_get() until new->lock is released.
 			 */
 			needs_asid = true;
 		}
 	}
-	SET_PTL0_ADDRESS(new->page_table);
-	mutex_unlock(&new->lock);
+	SET_PTL0_ADDRESS(replace->page_table);
+	mutex_unlock(&replace->lock);
 
 	if (needs_asid) {
@@ -923,7 +923,7 @@
 		
 		asid = asid_get();
-		mutex_lock_active(&new->lock);
-		new->asid = asid;
-		mutex_unlock(&new->lock);
+		mutex_lock_active(&replace->lock);
+		replace->asid = asid;
+		mutex_unlock(&replace->lock);
 	}
 	spinlock_unlock(&inactive_as_with_asid_lock);
@@ -934,7 +934,7 @@
 	 * (e.g. write ASID to hardware register etc.)
 	 */
-	as_install_arch(new);
-	
-	AS = new;
+	as_install_arch(replace);
+	
+	AS = replace;
 }
 
@@ -901,17 +901,17 @@
 		} else {
 			/*
-			 * Defer call to asid_get() until new->lock is released.
+			 * Defer call to asid_get() until replace->lock is released.
 			 */
 			needs_asid = true;
